# pylazycore

## struct

- src/lib.rs # declare functions
- src/core/ # store all core logic
- src/core/pdf/ # all pdf related logic
- src/core/models/ # all models for the detection
- src/core/extract/ # all functionality to extract data
- src/core/extract/data/ # all data organization related
- src/core/extract/detect/ # document detection module  
- src/core/extract/ocr/ # ocr functionality
- src/core/utils/ # core utility functions
- src/core/utils/ # extra python utility
